# isscratchup
Python module that checks if the Scratch website is up.

`.isUp()` - Returns true if Scratch appears to be up, returns false if not

`.apiHealth()` - Returns a JSON string from [api.scratch.mit.edu/health](https://api.scratch.mit.edu/health)
